Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon HealthLake.

Actions, resources, and condition keys for Amazon HealthLake - Service Authorization Reference

# Actions, resources, and condition keys for Amazon HealthLake

Amazon HealthLake (service prefix: `healthlake` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon HealthLake
- Resource types defined by Amazon HealthLake
- Condition keys for Amazon HealthLake

## Actions defined by Amazon HealthLake

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateFHIRDatastore | Grants permission to create a datastore that can ingest and export FHIR data | Write |  |  |
CreateResource | Grants permission to create resource | Write | datastore* |  |
DeleteFHIRDatastore | Grants permission to delete a datastore | Write | datastore* |  |
DeleteResource | Grants permission to delete resource | Write | datastore* |  |
DescribeFHIRDatastore | Grants permission to get the properties associated with the FHIR datastore, including the datastore ID, datastore ARN, datastore name, datastore status, created at, datastore type version, and datastore endpoint | Read | datastore* |  |
DescribeFHIRExportJob | Grants permission to display the properties of a FHIR export job, including the ID, ARN, name, and the status of the datastore | Read | datastore* |  |
DescribeFHIRImportJob | Grants permission to display the properties of a FHIR import job, including the ID, ARN, name, and the status of the datastore | Read | datastore* |  |
GetCapabilities | Grants permission to lists all FHIR datastores that are in the user’s account, regardless of datastore status | Read | datastore* |  |
ListFHIRDatastores | Grants permission to list all FHIR datastores that are in the user’s account, regardless of datastore status | List |  |  |
ReadResource | Grants permission to read resource | Read | datastore* |  |
SearchWithGet | Grants permission to search resources with GET method | Read | datastore* |  |
SearchWithPost | Grants permission to search resources with POST method | Read | datastore* |  |
StartFHIRExportJob | Grants permission to begin a FHIR Export job | Write | datastore* |  |
StartFHIRImportJob | Grants permission to begin a FHIR Import job | Write | datastore* |  |
UpdateResource | Grants permission to update resource | Write | datastore* |  |

## Resource types defined by Amazon HealthLake

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
datastore | `arn:$ { Partition}:healthlake:$ { Region}:$ { AccountId}:datastore/fhir/$ { DatastoreId}` |

## Condition keys for Amazon HealthLake

HealthLake has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.